def sub(a,*b):
	s=a
	for i in b:
		s=s-i
	print("the subraction of given numbers is-->",s)

# obj=kar()
# obj.sub(10,5,4)

# def sub(*a):
# 	# print(a[0])
# 	s=a[0]
# 	for i in a[1:]:
# 		s=s-i
# 	print("the subraction of given numbers is-->",s)
#
# sub(10,-7,5)
